@@ -52,8 +52,6 @@ extern int failure;
 extern int expected_conflicts;
 extern char *token_buffer;
 
-extern int atoi ();
-
 extern void init_lex();
 extern void tabinit();
 extern void output_headers();
@@ -1548,13 +1546,8 @@ record_rule_line ()
   if (nrules >= rline_allocated)
     {
       rline_allocated = nrules * 2;
-      rline = (short *) realloc (rline,
-				 rline_allocated * sizeof (short));
-      if (rline == 0)
-	{
-	  fprintf (stderr, "%s: memory exhausted\n", program_name);
-	  done (1);
-	}
+      rline = (short *) xrealloc (rline,
+				  rline_allocated * sizeof (short));
     }
   rline[nrules] = lineno;
 }
